﻿using UnityEngine;

namespace MacGruber
{
	public class FocusArea : MVRScript
	{
		private JSONStorableFloat myRadius;
		private JSONStorableFloat myHeight;
		private bool myHasRegisterRequest = false;

		public override void Init()
		{
			Utils.SetupInfoText(this,
				"<color=#606060><size=40><b>FocusArea</b></size>\nUsed by <i>VirtualLock</i> plugin to determine where the player is supposed to look at. You can place multiple <i>FocusArea</i> in the scene. For example put them each on an <i>Empty</i> atom parented to a character head or other bodyparts.</color>\n\n" +
				"Enable <i>'Draw Focus Areas'</i> on the <i>VirtualLock</i> plugin to visualize all your areas in the scene.",
				400.0f, true
			);

			myRadius = Utils.SetupSliderFloatWithRange(this, "Radius (cm)", 10.0f, 0.0f, 100.0f, false);
			myRadius.setCallbackFunction += (float val) => {
				if (myRadius.min < 0.0f)
					myRadius.min = 0.0f;
				if (val < 0.0f)
					myRadius.val = val = 0.0f;
				myHasRegisterRequest = true;
			};

			myHeight = Utils.SetupSliderFloatWithRange(this, "Height (cm)", 0.0f, 0.0f, 100.0f, false);
			myHeight.setCallbackFunction += (float val) => {
				if (myHeight.min < 0.0f)
					myHeight.min = 0.0f;
				if (val < 0.0f)
					myHeight.val = val = 0.0f;
				myHasRegisterRequest = true;
			};

			myHasRegisterRequest = true;
		}

		private void OnEnable()
		{
			myHasRegisterRequest = true;
		}

		private void OnDisable()
		{
			myHasRegisterRequest = false;
			Utils.SendMessageToPluginsInScene("MacGruber_VirtualLock_UnregisterFocusArea", this);
		}

		private void Update()
		{
			if (myHasRegisterRequest)
			{
				myHasRegisterRequest = false;
				Utils.SendMessageToPluginsInScene("MacGruber_VirtualLock_RegisterFocusArea", this);
			}
		}

		public void MacGruber_VirtualLock_RequestRegisterFocusArea()
		{
			OnEnable();
		}
	}
}